
<h1 align="center"><img src="deathFriends/sprints/death.png"></h1>

 <p>Death Friends is a third-person shooter in multiplayer format. The game is a dispute between 6 users, in which the winner is the one who survives.</p>

<h3 align="center">🚧  Death Friends 🚀 Under construction...  🚧</h3>

### Features


### Install

$ pip3 install deathFriends

Death Friends works with Python 3.6+.

To update it just run $ pip3 install --upgrade deathFriends.

### Play

Just run $ deathFriends.

